"""This module defines the CLI."""
import argparse
from pathlib import Path

import jinja2
import yaml

from stenciler import __desc__


def cli():
    """Main function."""
    # Inputs
    parser = argparse.ArgumentParser(__desc__)
    parser.add_argument(
        "-s", "--stencil", help="Path to stencil YAML file.", action="store"
    )
    parser.add_argument("-d", "--data", help="Path to data YAML file.", action="store")
    parser.add_argument(
        "-o",
        "--outdir",
        help="Output directory.",
        action="store",
        default=str(Path.cwd() / "outputs"),
    )
    args = parser.parse_args()
    outdir = Path(args.outdir)
    outdir.mkdir(exist_ok=True, parents=True)

    # Run
    with open(args.data, encoding="utf-8") as f:
        data = yaml.safe_load(f)
    with open(args.stencil, encoding="utf-8") as f:
        template_data = yaml.safe_load(f)
    for fmt, template_str in template_data.items():
        template = jinja2.Template(template_str)
        outpath = outdir / f"{Path(args.data).stem}.{fmt}"
        content = template.render(data)
        with open(outpath, "w", encoding="utf-8") as f:
            f.write(content)



"""Installation script for stenciler."""
from setuptools import find_packages, setup

from stenciler import __desc__

setup(
    name="stenciler",
    version="0.1.0",
    description=__desc__,
    author="Miles Butler",
    author_email="miles@milesbutler.dev",
    url="https://github.com/mtmbutler/stenciler",
    license="MIT",
    packages=["stenciler"] + ["stenciler." + i for i in find_packages("stenciler")],
    setup_requires=["wheel"],
    install_requires=[
        "pyyaml>=6.0",
        "Jinja2>=3.1",
    ],
    python_requires=">=3.6",
    entry_points={"console_scripts": ["stenciler = stenciler.cli:cli"]},
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Text Processing",
    ],
)
